@@ -1,7 +1,8 @@
 import argparse
 import logging
 import os
-from typing import List, Optional, Text
+from pathlib import Path
+from typing import List, Optional, Text, Union
 
 from rasa import model
 from rasa.cli import SubParsersAction
@@ -15,6 +16,7 @@ from rasa.shared.importers.importer import TrainingDataImporter
 import rasa.shared.utils.cli
 import rasa.utils.common
 
+
 logger = logging.getLogger(__name__)
 
 
@@ -67,7 +69,7 @@ def interactive(args: argparse.Namespace) -> None:
                 "data or a model containing core data."
             )
 
-        zipped_model = (
+        zipped_model: Optional[Union[Text, Path]] = (
             train.run_core_training(args)
             if args.core_only
             else train.run_training(args)
@@ -99,7 +101,9 @@ def _set_not_required_args(args: argparse.Namespace) -> None:
 
 
 def perform_interactive_learning(
-    args: argparse.Namespace, zipped_model: Text, file_importer: TrainingDataImporter
+    args: argparse.Namespace,
+    zipped_model: Union[Text, "Path"],
+    file_importer: TrainingDataImporter,
 ) -> None:
     """Performs interactive learning.
 
@@ -110,7 +114,7 @@ def perform_interactive_learning(
     """
     from rasa.core.train import do_interactive_learning
 
-    args.model = zipped_model
+    args.model = str(zipped_model)
 
     metadata = LocalModelStorage.metadata_from_archive(zipped_model)
     if metadata.training_type == TrainingType.NLU:
@@ -125,13 +129,12 @@ def perform_interactive_learning(
     do_interactive_learning(args, file_importer)
 
 
-def get_provided_model(arg_model: Text) -> Optional[Text]:
+def get_provided_model(arg_model: Text) -> Optional[Union[Text, Path]]:
     """Checks model path input and selects model from it."""
     model_path = rasa.cli.utils.get_validated_path(
         arg_model, "model", DEFAULT_MODELS_PATH
     )
 
-    if os.path.isdir(model_path):
-        model_path = model.get_latest_model(model_path)
-
-    return model_path
+    return (
+        model.get_latest_model(model_path) if os.path.isdir(model_path) else model_path
+    )
