@@ -1,7 +1,16 @@
 import copy
 import logging
 import os
-from typing import Text, Dict, Optional, List, Any, Iterable, Tuple, Union
+from typing import (
+    Text,
+    Dict,
+    Optional,
+    List,
+    Any,
+    Iterable,
+    Tuple,
+    Union,
+)
 from pathlib import Path
 
 from rasa.core.agent import Agent
@@ -18,6 +27,7 @@ from rasa.shared.data import TrainingType
 from rasa.shared.nlu.training_data.training_data import TrainingData
 import rasa.model
 
+
 logger = logging.getLogger(__name__)
 
 
