@@ -1,11 +1,11 @@
-from typing import Any, Dict, List, Text, Tuple, Optional, NamedTuple
+import abc
+from typing import Any, Dict, List, NamedTuple, Text, Tuple, Optional
 
 import rasa.shared.utils.io
 from rasa.shared.constants import DOCS_URL_TRAINING_DATA_NLU
 from rasa.shared.nlu.training_data.training_data import TrainingData
 from rasa.shared.nlu.training_data.message import Message
 from rasa.nlu.tokenizers.tokenizer import Token
-from rasa.nlu.components import Component
 from rasa.nlu.constants import (
     TOKENS_NAMES,
     ENTITY_ATTRIBUTE_CONFIDENCE_TYPE,
@@ -25,7 +25,6 @@ from rasa.shared.nlu.constants import (
     ENTITY_ATTRIBUTE_ROLE,
     NO_ENTITY_TAG,
     SPLIT_ENTITIES_BY_COMMA,
-    SPLIT_ENTITIES_BY_COMMA_DEFAULT_VALUE,
     SINGLE_ENTITY_ALLOWED_INTERLEAVING_CHARSET,
 )
 import rasa.utils.train_utils
@@ -40,13 +39,19 @@ class EntityTagSpec(NamedTuple):
     num_tags: int
 
 
-class EntityExtractor(Component):
-    """Entity extractors are components which extract entities.
+class EntityExtractorMixin(abc.ABC):
+    """Provides functionality for components that do entity extraction.
 
-    They can be placed in the pipeline like other components, and can extract
-    entities like a person's name, or a location.
+    Inheriting from this class will add utility functions for entity extraction.
+    Entity extraction is the process of identifying and extracting entities like a
+    person's name, or a location from a message.
     """
 
+    @property
+    def name(self) -> Text:
+        """Returns the name of the class."""
+        return self.__class__.__name__
+
     def add_extractor_name(
         self, entities: List[Dict[Text, Any]]
     ) -> List[Dict[Text, Any]]:
@@ -78,24 +83,6 @@ class EntityExtractor(Component):
 
         return entity
 
-    def init_split_entities(self) -> Dict[Text, bool]:
-        """Initialises the behaviour for splitting entities by comma (or not).
-
-        Returns:
-            Defines desired behaviour for splitting specific entity types and
-            default behaviour for splitting any entity types for which no
-            behaviour is defined.
-        """
-        split_entities_config = self.component_config.get(
-            SPLIT_ENTITIES_BY_COMMA, SPLIT_ENTITIES_BY_COMMA_DEFAULT_VALUE
-        )
-        default_value = self.defaults.get(
-            SPLIT_ENTITIES_BY_COMMA, SPLIT_ENTITIES_BY_COMMA_DEFAULT_VALUE
-        )
-        return rasa.utils.train_utils.init_split_entities(
-            split_entities_config, default_value
-        )
-
     @staticmethod
     def filter_irrelevant_entities(extracted: list, requested_dimensions: set) -> list:
         """Only return dimensions the user configured."""
@@ -195,7 +182,7 @@ class EntityExtractor(Component):
         last_token_end = -1
 
         for idx, token in enumerate(tokens):
-            current_entity_tag = EntityExtractor.get_tag_for(
+            current_entity_tag = EntityExtractorMixin.get_tag_for(
                 tags, ENTITY_ATTRIBUTE_TYPE, idx
             )
 
@@ -204,11 +191,11 @@ class EntityExtractor(Component):
                 last_token_end = token.end
                 continue
 
-            current_group_tag = EntityExtractor.get_tag_for(
+            current_group_tag = EntityExtractorMixin.get_tag_for(
                 tags, ENTITY_ATTRIBUTE_GROUP, idx
             )
             current_group_tag = bilou_utils.tag_without_prefix(current_group_tag)
-            current_role_tag = EntityExtractor.get_tag_for(
+            current_role_tag = EntityExtractorMixin.get_tag_for(
                 tags, ENTITY_ATTRIBUTE_ROLE, idx
             )
             current_role_tag = bilou_utils.tag_without_prefix(current_role_tag)
@@ -250,7 +237,7 @@ class EntityExtractor(Component):
 
             if new_tag_found:
                 # new entity found
-                entity = EntityExtractor._create_new_entity(
+                entity = EntityExtractorMixin._create_new_entity(
                     list(tags.keys()),
                     current_entity_tag,
                     current_group_tag,
@@ -260,7 +247,7 @@ class EntityExtractor(Component):
                     confidences,
                 )
                 entities.append(entity)
-            elif EntityExtractor._check_is_single_entity(
+            elif EntityExtractorMixin._check_is_single_entity(
                 text, token, last_token_end, split_entities_config, current_entity_tag
             ):
                 # current token has the same entity tag as the token before and
@@ -269,7 +256,7 @@ class EntityExtractor(Component):
                 # and a whitespace.
                 entities[-1][ENTITY_ATTRIBUTE_END] = token.end
                 if confidences is not None:
-                    EntityExtractor._update_confidence_values(
+                    EntityExtractorMixin._update_confidence_values(
                         entities, confidences, idx
                     )
 
@@ -278,7 +265,7 @@ class EntityExtractor(Component):
                 # tokens are separated by at least 2 symbols (e.g. multiple spaces,
                 # a comma and a space, etc.) and also shouldn't be represented as a
                 # single entity
-                entity = EntityExtractor._create_new_entity(
+                entity = EntityExtractorMixin._create_new_entity(
                     list(tags.keys()),
                     current_entity_tag,
                     current_group_tag,
