@@ -67,8 +67,8 @@ class JiebaTokenizer(Tokenizer):
             cls._load_custom_dictionary(dictionary_path)
         return cls(config, model_storage, resource)
 
-    @classmethod
-    def required_packages(cls) -> List[Text]:
+    @staticmethod
+    def required_packages() -> List[Text]:
         """Any extra python dependencies required for this component to run."""
         return ["jieba"]
 
