@@ -69,7 +69,7 @@ if TYPE_CHECKING:
     EntityPrediction = TypedDict(
         "EntityPrediction",
         {
-            ENTITY_ATTRIBUTE_TEXT: Text,
+            ENTITY_ATTRIBUTE_TEXT: Text,  # type: ignore[misc]
             ENTITY_ATTRIBUTE_START: Optional[float],
             ENTITY_ATTRIBUTE_END: Optional[float],
             ENTITY_ATTRIBUTE_VALUE: Text,
@@ -83,11 +83,12 @@ if TYPE_CHECKING:
     )
 
     IntentPrediction = TypedDict(
-        "IntentPrediction", {INTENT_NAME_KEY: Text, PREDICTED_CONFIDENCE_KEY: float}
+        "IntentPrediction", {INTENT_NAME_KEY: Text, PREDICTED_CONFIDENCE_KEY: float}  # type: ignore[misc]  # noqa: E501
     )
     NLUPredictionData = TypedDict(
         "NLUPredictionData",
         {
+            TEXT: Text,  # type: ignore[misc]
             INTENT: IntentPrediction,
             INTENT_RANKING_KEY: List[IntentPrediction],
             ENTITIES: List[EntityPrediction],
@@ -141,7 +142,7 @@ def format_message(
 
     Return:
         Message with entities annotated inline, e.g.
-        `I am from [Berlin]{"entity": "city"}`.
+        `I am from [Berlin]{`"`entity`"`: `"`city`"`}`.
     """
     from rasa.shared.nlu.training_data.formats.readerwriter import TrainingDataWriter
     from rasa.shared.nlu.training_data import entities_parser
@@ -465,7 +466,7 @@ class UserUttered(Event):
             self.use_text_for_featurization = False
 
         self.parse_data: "NLUPredictionData" = {
-            INTENT: self.intent,
+            INTENT: self.intent,  # type: ignore[misc]
             # Copy entities so that changes to `self.entities` don't affect
             # `self.parse_data` and hence don't get persisted
             ENTITIES: self.entities.copy(),
@@ -533,14 +534,14 @@ class UserUttered(Event):
         """Returns text representation of event."""
         entities = ""
         if self.entities:
-            entities = [
+            entities_list = [
                 f"{entity[ENTITY_ATTRIBUTE_VALUE]} "
                 f"(Type: {entity[ENTITY_ATTRIBUTE_TYPE]}, "
                 f"Role: {entity.get(ENTITY_ATTRIBUTE_ROLE)}, "
                 f"Group: {entity.get(ENTITY_ATTRIBUTE_GROUP)})"
                 for entity in self.entities
             ]
-            entities = f", entities: {', '.join(entities)}"
+            entities = f", entities: {', '.join(entities_list)}"
 
         return (
             f"UserUttered(text: {self.text}, intent: {self.intent_name}"
